@@ -613,7 +613,6 @@ gather_object_summary_cb (EMapiConnection *conn,
 			const gchar *subject, *message_id, *references, *in_reply_to, *display_to, *display_cc;
 			const struct FILETIME *delivery_time, *submit_time;
 			const uint32_t *msg_size;
-			gint offset = 0;
 			gchar *formatted_addr, *from_name, *from_email;
 			CamelAddress *to_addr, *cc_addr, *bcc_addr;
 
@@ -637,9 +636,9 @@ gather_object_summary_cb (EMapiConnection *conn,
 			minfo->info.size = msg_size ? *msg_size : 0;
 
 			if (minfo->info.date_sent != 0)
-				minfo->info.date_sent = camel_header_decode_date (ctime (&minfo->info.date_sent), &offset);
+				minfo->info.date_sent = minfo->info.date_sent;
 			if (minfo->info.date_received != 0)
-				minfo->info.date_received = camel_header_decode_date (ctime (&minfo->info.date_received), &offset);
+				minfo->info.date_received = minfo->info.date_received;
 
 			/* Threading related properties */
 			mapi_set_message_id (minfo, message_id);
@@ -732,7 +731,7 @@ gather_object_summary_cb (EMapiConnection *conn,
 gboolean
 camel_mapi_folder_fetch_summary (CamelFolder *folder, GCancellable *cancellable, GError **mapi_error)
 {
-	gboolean status;
+	gboolean status, has_obj_folder;
 	gboolean full_download;
 	CamelSettings *settings;
 	CamelStore *store = camel_folder_get_parent_store (folder);
@@ -773,6 +772,7 @@ camel_mapi_folder_fetch_summary (CamelFolder *folder, GCancellable *cancellable,
 	}
 
 	status = cmf_open_folder (mapi_folder, conn, &obj_folder, cancellable, mapi_error);
+	has_obj_folder = status;
 
 	if (status) {
 		status = e_mapi_connection_get_folder_properties (conn, &obj_folder, NULL, NULL, e_mapi_utils_get_folder_basic_properties_cb, &fbp, cancellable, mapi_error);
@@ -850,7 +850,8 @@ camel_mapi_folder_fetch_summary (CamelFolder *folder, GCancellable *cancellable,
 		camel_folder_change_info_free (gos.changes);
 	}
 
-	e_mapi_connection_close_folder (conn, &obj_folder, cancellable, mapi_error);
+	if (has_obj_folder)
+		e_mapi_connection_close_folder (conn, &obj_folder, cancellable, mapi_error);
 
 	g_slist_free_full (gco.to_update, g_free);
 	if (gco.removed_uids)
