@@ -127,6 +127,7 @@ e_mapi_book_utils_contact_from_object (EMapiConnection *conn,
 				       const gchar *book_uri)
 {
 	EContact *contact;
+	gchar *email_1;
 	const mapi_id_t *pmid;
 	gint i;
 
@@ -341,13 +342,16 @@ e_mapi_book_utils_contact_from_object (EMapiConnection *conn,
 		}
 	}
 
-	if (!e_contact_get (contact, E_CONTACT_EMAIL_1)) {
+	email_1 = e_contact_get (contact, E_CONTACT_EMAIL_1);
+	if (!email_1) {
 		gconstpointer value = get_proptag (PidTagPrimarySmtpAddress);
 
 		if (value)
 			e_contact_set (contact, E_CONTACT_EMAIL_1, value);
 	}
 
+	g_free (email_1);
+
 	#undef get_proptag
 	#undef get_str_proptag
 
@@ -684,8 +688,14 @@ term_eval_and (struct _ESExp *f,
 		if (argv[ii]->type == ESEXP_RES_INT &&
 		    argv[ii]->value.number >= 0 && 
 		    argv[ii]->value.number < esp->res_parts->len) {
+			struct mapi_SRestriction *subres = g_ptr_array_index (esp->res_parts, argv[ii]->value.number);
+
 			jj = argv[ii]->value.number;
 			valid++;
+
+			/* join two consecutive AND-s into one */
+			if (subres->rt == RES_AND)
+				valid += subres->res.resAnd.cRes - 1;
 		}
 	}
 
@@ -707,10 +717,20 @@ term_eval_and (struct _ESExp *f,
 			    argv[ii]->value.number < esp->res_parts->len) {
 				struct mapi_SRestriction *subres = g_ptr_array_index (esp->res_parts, argv[ii]->value.number);
 
-				res->res.resAnd.res[jj].rt = subres->rt;
-				res->res.resAnd.res[jj].res = subres->res;
+				/* join two consecutive AND-s into one */
+				if (subres->rt == RES_AND) {
+					gint xx;
 
-				jj++;
+					for (xx = 0; xx < subres->res.resAnd.cRes; xx++, jj++) {
+						res->res.resAnd.res[jj].rt = subres->res.resAnd.res[xx].rt;
+						res->res.resAnd.res[jj].res = subres->res.resAnd.res[xx].res;
+					}
+				} else {
+					res->res.resAnd.res[jj].rt = subres->rt;
+					res->res.resAnd.res[jj].res = subres->res;
+
+					jj++;
+				}
 			}
 		}
 
@@ -738,8 +758,14 @@ term_eval_or (struct _ESExp *f,
 		if (argv[ii]->type == ESEXP_RES_INT &&
 		    argv[ii]->value.number >= 0 && 
 		    argv[ii]->value.number < esp->res_parts->len) {
+			struct mapi_SRestriction *subres = g_ptr_array_index (esp->res_parts, argv[ii]->value.number);
+
 			jj = argv[ii]->value.number;
 			valid++;
+
+			/* join two consecutive OR-s into one */
+			if (subres->rt == RES_OR)
+				valid += subres->res.resOr.cRes - 1;
 		    }
 	}
 
@@ -761,10 +787,20 @@ term_eval_or (struct _ESExp *f,
 			    argv[ii]->value.number < esp->res_parts->len) {
 				struct mapi_SRestriction *subres = g_ptr_array_index (esp->res_parts, argv[ii]->value.number);
 
-				res->res.resOr.res[jj].rt = subres->rt;
-				res->res.resOr.res[jj].res = subres->res;
+				/* join two consecutive OR-s into one */
+				if (subres->rt == RES_OR) {
+					gint xx;
 
-				jj++;
+					for (xx = 0; xx < subres->res.resOr.cRes; xx++, jj++) {
+						res->res.resOr.res[jj].rt = subres->res.resOr.res[xx].rt;
+						res->res.resOr.res[jj].res = subres->res.resOr.res[xx].res;
+					}
+				} else {
+					res->res.resOr.res[jj].rt = subres->rt;
+					res->res.resOr.res[jj].res = subres->res;
+
+					jj++;
+				}
 			}
 		}
 
@@ -980,7 +1016,7 @@ func_eval_field_exists (struct _ESExp *f,
 			res->res.resOr.res[0].res.resExist.ulPropTag = PidTagPrimarySmtpAddress;
 
 			for (ii = 1, jj = 0; emails[jj]; jj++) {
-				proptag = get_proptag_from_field_name ("email_1", TRUE);
+				proptag = get_proptag_from_field_name (emails[jj], TRUE);
 
 				if (proptag == MAPI_E_RESERVED)
 					continue;
