@@ -56,7 +56,6 @@ typedef struct {
 
 typedef struct {
 	mapi_id_t mid;		/* message ID, from PidTagMid */
-	uint32_t obj_type;	/* PidTagObjectType */
 	const gchar *msg_class;	/* PidTagMessageClass */
 	uint32_t msg_flags;	/* MAPI MSGFLAG_* bit OR, from PidTagMessageFlags */
 	time_t last_modified;	/* PidTagLastModificationTime as UTC */
@@ -66,6 +65,7 @@ typedef struct _EMapiStreamedProp {
 	uint32_t proptag;
 	uint64_t cb;
 	const uint8_t *lpb; /* taken from the original mapi prop, no need to copy the memory */
+	gconstpointer orig_value; /* exact original value, as stored inside mapi prop; the lpb can be converted to utf16 */
 } EMapiStreamedProp;
 
 typedef struct _EMapiRecipient EMapiRecipient;
